@@ -11,10 +11,12 @@ class Wallet(APIBase):
     def details(self, wallet_id):
         return self.send_request("GET", f"wallets/{wallet_id}", None)
 
-    def create(self, currency):
+    def create(self, currency, label, can_disburse=False):
         payload = {
             "wallet_type": "WORKING",
-            "currency": currency
+            "currency": currency,
+            "label": label,
+            "can_disburse": can_disburse
         }
         return self.send_request("POST", "wallets/", payload)
 
@@ -35,4 +37,4 @@ class Wallet(APIBase):
         return self.send_request("POST", f"wallets/{origin_id}/intra_transfer/", payload=payload)
 
     def fund(self, wallet_id, phone_number, email, amount, narrative, currency="KES", api_ref="API Request", name=None):
-        return self.collect.mpesa(phone_number=phone_number, email=email, amount=amount, narrative=narrative, currency=currency, api_ref=api_ref, name=name)
+        return self.collect.mpesa_stk_push(phone_number=phone_number, email=email, amount=amount, narrative=narrative, currency=currency, api_ref=api_ref, name=name)
